@@ -20,26 +20,93 @@
 
 ================================================================================
 
-	The progressions module is here to easily indentify and generate
-	chords from progressions and vice versa.
+	In music and music theory you often deal with sequences 
+	of chords. These chord sequences are called progressions and are
+	often written down using roman numerals. In this system the 'I' 
+	refers to the first natural triad in a key, the II to the second,
+	etc. We can add prefixes and suffixes to denote more complex 
+	progressions, like: #V7, bIIdim7, etc.
+
+	This module provides methods which can convert progressions 
+	to chords and vice versa.
 
 ================================================================================
 
 """
 
+import notes
 import chords
 import intervals
 
-jazz = ["ii7", "V7", "I7"]
-
-standard_blues = ["I", "I", "I", "I",\
-				  "IV", "IV", "I", "I",\
-				  "V7", "V7", "IV", "IV"]
 
 def to_chords(progression, key = 'C'):
-	"""Converts a list of chord functions (eg `['I', 'V7']`) to \
-a list of chords."""
-	return map(lambda x: chords.__dict__[x](key), progression)
+	"""Converts a list of chord functions (eg `['I', 'V7']`) or \
+a string (eg. 'I7') to a list of chords. \
+Any number of accidentals can be used as prefix to augment or diminish; \
+for example: bIV or #I. All the chord abbreviations in the chord module \
+can be used as suffixes; for example: Im7, IVdim7, etc. \
+You can combine prefixes and suffixes to manage complex progressions: \
+#vii7, #iidim7, iii7, etc. \
+Using 7 as suffix is ambiguous, since it is classicly used to denote \
+the seventh chord when talking about progressions instead of _just_ the \
+dominanth seventh chord. We have taken the classic route; I7 \
+will get you a major seventh chord. If you specifically want a dominanth \
+seventh, use Idom7."""
+
+	if type(progression) == str:
+		progression = [progression]
+
+	result = []
+	for chord in progression:
+		
+		# strip preceding accidentals from the string
+		acc = 0
+		roman_numeral = ""
+		suffix = ""
+		i =0 
+
+		for c in chord:
+			if c == '#':
+				acc += 1
+			elif c == 'b':
+				acc -= 1
+			elif c.upper() == 'I' or c.upper() == 'V':
+				roman_numeral += c.upper()
+			else:
+				break
+			i += 1
+		suffix = chord[i:]
+
+		# There is no roman numeral parsing, just a simple check.
+		# Sorry to disappoint.
+		#warning Should throw exception
+		if roman_numeral not in ['I', 'II', 'III', 'IV',\
+					'V', 'VI', 'VII']:
+			return []
+
+		# These suffixes don't need any post processing
+		if suffix == '7' or suffix == '':
+			roman_numeral += suffix
+
+			# ahh Python. Everything is a dict.
+			r = chords.__dict__[roman_numeral](key)
+		else:
+			r = chords.__dict__[roman_numeral](key)
+			r = chords.chord_shorthand[suffix](r[0])
+
+
+		# Let the accidentals do their work
+		while acc < 0:
+			r = map(notes.diminish, r)
+			acc += 1
+		while acc > 0:
+			r = map(notes.augment, r)
+			acc -= 1
+
+		result.append(r)
+	return result
+	
+
 
 def determine(chord, key, shorthand = False):
 	"""Determines the harmonic function of chord in key. This function can \
